**SETUP**
*load data -- these data were obtained online from the Angrist Archive on 5/22/2010
use cps3re74.dta, clear //observational sample
*use nswre74.dta, clear //experimental sample


set seed 12345

***COMPARISON OF WEIGHTS***

**Logit Weights**
logit treat age age2 ed black hisp married nodeg re75 re74
keep if e(sample)==1 //DROP OBS WITH MISSING COVARIATES

predict p
sum treat
local pi=r(mean)
local N1=r(sum)
local N0=r(N)-`N1'
gen wlogit=p/(1-p)*(1-`pi')/`pi' if treat==0


**OB Weights**
gen one=1
gen w=.
gen nD=1-treat
mata: X=st_data(.,("one", "age", "age2", "ed", "black", "hisp", "married", "nodeg", "re75", "re74"))
mata: D=st_data(.,"treat")
mata: nD=st_data(.,"nD")
mata: w=D'*X*invsym(quadcross(X,nD,X))*X'/`N1'
mata: w=w':*nD
mata: st_store(.,"w",w)


gen wplot=w*`N1' //renormalize the weights to have mean 1
scatter wplot wlogit if wlogit!=., scheme(s2mono) xtitle("Logit Weight") ytitle("Oaxaca-Blinder Weight") title("Oaxaca-Blinder vs. Logit Weights")


**Check Balancing Properties of Weights**
sum age  if treat==1
sum age  if treat==0

sum age [aw=wlogit] if treat==0 //inexact balance
sum age [iw=w] if treat==0 //exact balance




***TREATMENT EFFECTS***


**Naive**
reg re78 treat, robust


**OLS**
reg re78 treat age age2 ed black hisp married nodeg re75 re74, robust


**IPW**

*define short reweighting program
drop p wlogit
cap prog drop TOT_logit
prog def TOT_logit, rclass
logit treat age age2 ed black hisp married nodeg re75 re74
predict p
gen wlogit=p/(1-p) if treat==0
replace wlogit=1 if treat==1
reg re78 treat [aw=wlogit]
drop p wlogit
return scalar b=_b[treat]
ereturn clear
end

*bootstrap
bs "TOT_logit" b=r(b), reps(1000)


**OB**
reg re78 one age age2 ed black hisp married nodeg re75 re74 if treat==0, nocons robust

mat b=e(b)
mat V0=e(V)

predict Y0
gen dif=re78-Y0

sum dif if treat==1
local TOT=r(mean)


sum re78 if treat==1
local V1=r(Var)/r(N)
local mu1=r(mean)

mata: V0=st_matrix("V0")
mata: V1=`V1'
mata: Vdif=V1+D'*X*V0*X'*D/(`N1'^2)
mata: st_numscalar("Vdif",Vdif)

di "TOT is `TOT', se is " sqrt(Vdif)
